@@ -12,7 +12,7 @@ from sqlalchemy.sql.sqltypes import Numeric
 SLOG = structlog.get_logger(__name__)
 
 
-VALID_COLUMN_RE = re.compile("^\w+$")
+VALID_COLUMN_RE = re.compile("^\w[\w ]*$")
 
 
 def is_valid_column(colname: str) -> bool:
@@ -45,6 +45,11 @@ class Col:
                 datatype = "num"
             elif isinstance(sqla_col.type, Boolean):
                 datatype = "bool"
+            elif str(sqla_col.type).startswith("TIMESTAMP"):
+                # This check is to support snowflake which uses custom
+                # types for timestamps that are not derived from sqlalchemy
+                # types.
+                datatype = "datetime"
             else:
                 datatype = "unusable"
             return cls(
@@ -91,7 +96,10 @@ class Col:
         return f"{self.namespace}\\.{self.name}" if self.namespace else self.name
 
     def as_rule(self):
-        return f'    {self.rule_name}: "[" + /{self.field_name}/i + "]" | /{self.field_name}/i'
+        if " " in self.field_name:
+            return f'    {self.rule_name}: "[" + /{self.field_name}/i + "]"'
+        else:
+            return f'    {self.rule_name}: "[" + /{self.field_name}/i + "]" | /{self.field_name}/i'
 
 
 @attr.s
@@ -143,7 +151,9 @@ def make_column_collection_for_selectable(
     elif hasattr(selectable, "c") and isinstance(selectable.c, ColumnCollection):
         column_iterable = selectable.c
     else:
-        raise Exception("Selectable does not have columns")
+        raise Exception(
+            f"Selectable must be a Table or ColumnCollection, this is a {type(selectable)}"
+        )
 
     columns = []
     for sqla_col in column_iterable:
@@ -273,13 +283,13 @@ def make_grammar(columns):
     {make_columns_grammar(columns)}
 
     {gather_columns("unusable_col", columns, "unusable")}
-    {gather_columns("date.1", columns, "date", additional_rules=["date_conv", "date_fn", "day_conv", "week_conv", "month_conv", "quarter_conv", "year_conv", "dt_day_conv", "dt_week_conv", "dt_month_conv", "dt_quarter_conv", "dt_year_conv", "datetime_to_date_conv", "date_aggr", "date_if_statement", "date_coalesce"])}
+    {gather_columns("date.1", columns, "date", additional_rules=["date_conv", "date_fn", "day_conv", "week_conv", "month_conv", "quarter_conv", "year_conv", "dt_day_conv", "dt_week_conv", "dt_month_conv", "dt_quarter_conv", "dt_year_conv", "datetime_to_date_conv", "date_aggr", "date_if_statement", "date_coalesce", "lastday"])}
     {gather_columns("datetime.2", columns, "datetime", additional_rules=["datetime_conv", "datetime_if_statement", "datetime_coalesce"])}
     // Datetimes that are converted to the end of day
     {gather_columns("datetime_end.1", columns, "datetime", additional_rules=["datetime_end_conv", "datetime_aggr"])}
     {gather_columns("boolean.1", columns, "bool", additional_rules=["TRUE", "FALSE", "bool_expr", "date_bool_expr", "datetime_bool_expr", "str_like_expr", "vector_expr", "between_expr", "date_between_expr", "datetime_between_expr", "not_boolean", "or_boolean", "and_boolean", "paren_boolean", "intelligent_date_expr", "intelligent_datetime_expr"])}
     {gather_columns("string.1", columns, "str", additional_rules=["ESCAPED_STRING", "string_add", "string_cast", "string_coalesce", "string_substr", "string_if_statement", "string_aggr"])}
-    {gather_columns("num.1", columns, "num", additional_rules=["NUMBER", "num_add", "num_sub", "num_mul", "num_div", "int_cast", "num_coalesce", "aggr", "error_aggr", "num_if_statement", "age_conv"])}
+    {gather_columns("num.1", columns, "num", additional_rules=["NUMBER", "num_add", "num_sub", "num_mul", "num_div", "int_cast", "num_coalesce", "aggr", "error_aggr", "num_if_statement", "age_conv", "datediff", "extract"])}
     string_add: string "+" string
     num_add.1: num "+" num | "(" num "+" num ")"
     num_sub.1: num "-" num | "(" num "-" num ")"
@@ -352,6 +362,10 @@ def make_grammar(columns):
     dt_month_conv: /month/i "(" datetime ")"
     dt_quarter_conv: /quarter/i "(" datetime ")"
     dt_year_conv: /year/i "(" datetime ")"
+    /// date->int
+    datediff: /datediff/i "(" date "," date ("," DATEPART )? ")"
+    extract: /extract/i "(" DATEPART "," (date | datetime) ")"
+    lastday: /lastday/i "(" (date | datetime) ("," DATEPART )? ")"
     // col->string
     string_cast: /string/i "(" col ")"
     string_substr: /substr/i "(" string "," [num ("," num)?] ")"
@@ -419,6 +433,8 @@ def make_grammar(columns):
     IF: /IF/i
     INTELLIGENT_DATE_OFFSET: /prior/i | /last/i | /previous/i | /current/i | /this/i | /next/i
     INTELLIGENT_DATE_UNITS: /ytd/i | /year/i | /qtr/i | /month/i | /mtd/i | /day/i
+    DATEPART: /dayofweek/i | /day/i | /dayofyear/i | /week/i | /week/i "(" WEEKDAY ")" | /month/i | /quarter/i | /year/i | /isoyear/i | /isoweek/i
+    WEEKDAY: /monday/i | /tuesday/i | /wednesday/i | /thursday/i | /friday/i | /saturday/i | /sunday/i
     COMMENT: /#.*/
 
     %import common.CNAME                       -> NAME
