@@ -355,6 +355,32 @@ class TransformToSQLAlchemyExpression(Transformer):
     def timedelta(self):
         pass
 
+    def datediff(self, _, dt1, dt2, datepart="day"):
+        if self.drivername == "bigquery":
+            return func.date_diff(dt1, dt2, text(datepart))
+        elif self.drivername == "sqlite":
+            return cast(func.julianday(dt1), Integer()) - cast(
+                func.julianday(dt2), Integer()
+            )
+        else:
+            # This works for postgres and mssql
+            return func.datediff(text(datepart), dt1, dt2)
+
+    def extract(self, _, datepart, dt):
+        if self.drivername == "bigquery":
+            return func.extract(text(datepart), dt)
+        elif self.drivername == "sqlite":
+            raise GrammarError("Sqlite does not support extract")
+        else:
+            # This works for postgres and mssql
+            return func.extract(text(datepart), dt)
+
+    def lastday(self, _, dt, datepart="month"):
+        if self.drivername in ("bigquery", "snowflake"):
+            return func.last_day(dt, text(datepart))
+        else:
+            raise GrammarError(f"{self.drivername} does not support lastday")
+
     # Booleans
 
     def and_boolean(self, left_boolean, AND, right_boolean):
