@@ -1,21 +1,21 @@
 import contextlib
+from collections import OrderedDict
 from copy import copy
+from dataclasses import dataclass, field
+from typing import Optional, List, Dict
 
 from lark.exceptions import VisitError
-from collections import OrderedDict
 from sqlalchemy import Float, Integer, String, Table
 from sqlalchemy.util import lightweight_named_tuple
 from sureberus import errors as E
 from sureberus import normalize_schema
 from yaml import safe_load
-from dataclasses import dataclass, field
 
 from recipe.exceptions import BadIngredient, BadRecipe, InvalidColumnError
-from recipe.ingredients import Dimension, Filter, Ingredient, Metric, InvalidIngredient
+from recipe.ingredients import Dimension, Filter, Ingredient, InvalidIngredient, Metric
 from recipe.schemas import shelf_schema
-from recipe.schemas.parsed_constructors import create_ingredient_from_parsed
-
 from recipe.schemas.builders import SQLAlchemyBuilder
+from recipe.schemas.parsed_constructors import create_ingredient_from_parsed
 
 _POP_DEFAULT = object()
 
@@ -90,7 +90,7 @@ class SelectParts:
         for key in self.raw_order_by_keys:
             with contextlib.suppress(BadRecipe):
                 ingr = shelf.find(key, (Dimension, Metric))
-                for c in ingr.order_by_columns:
+                for c in ingr.order_by_columns(engine=shelf.Meta.engine):
                     # Avoid duplicate order by columns
                     if str(c) not in [str(o) for o in validated_order_bys]:
                         validated_order_bys[c] = None
@@ -118,6 +118,7 @@ class Shelf(object):
         select_from = None
         ingredient_order = []
         metadata = None
+        engine = None
 
     def __init__(self, *args, **kwargs):
         self.Meta = type(self).Meta()
@@ -125,6 +126,7 @@ class Shelf(object):
         self.Meta.table = kwargs.pop("table", None)
         self.Meta.select_from = kwargs.pop("select_from", None)
         self.Meta.metadata = kwargs.pop("metadata", None)
+        self.Meta.engine = kwargs.pop("engine", None)
         self._ingredients = {}
         self.update(*args, **kwargs)
 
@@ -264,10 +266,7 @@ class Shelf(object):
         """A string representation of the ingredients used in a recipe
         ordered by Dimensions, Metrics, Filters, then Havings
         """
-        lines = []
-        # sort the ingredients by type
-        for ingredient in sorted(self.values()):
-            lines.append(ingredient.describe())
+        lines = [ingredient.describe() for ingredient in sorted(self.values())]
         return "\n".join(lines)
 
     def use(self, ingredient):
@@ -284,14 +283,15 @@ class Shelf(object):
     @classmethod
     def from_config(
         cls,
-        obj,
+        obj: Dict,
         selectable,
         ingredient_constructor=None,
         metadata=None,
         *,
+        builder: Optional[SQLAlchemyBuilder] = None,
         ingredient_cache=None,
-        extra_selectables=None,
-        constants=None,
+        extra_selectables: Optional[List] = None,
+        constants: Optional[Dict] = None,
     ):
         """Create a shelf using a dict shelf definition.
 
@@ -304,48 +304,57 @@ class Shelf(object):
             order to introspect its schema, we must have the SQLAlchemy
             MetaData object to associate it with.
         :param ingredient_cache: An optional cache for improving parse times
-        :param extra_selectables: A dict with keys of namespace and selectable
+        :param extra_selectables: A list of (selectable, namespace) tuples.
             these are extra selectables that can be used in expressions
         :return: A shelf that contains the ingredients defined in obj.
         """
-        from recipe import Recipe
-
-        constants = constants or {}
-
-        if isinstance(selectable, Recipe):
-            selectable = selectable.subquery()
-        elif isinstance(selectable, str):
-            if "." in selectable:
-                schema, tablename = selectable.split(".")
-            else:
-                schema, tablename = None, selectable
-
-            selectable = Table(
-                tablename, metadata, schema=schema, extend_existing=True, autoload=True
-            )
 
         try:
             validated_shelf = normalize_schema(shelf_schema, obj, allow_unknown=True)
         except E.SureError as e:
             raise BadIngredient(str(e))
+
         d = {}
-        builder = None
+        if builder is None:
+            from recipe import Recipe
+
+            constants = constants or {}
+
+            if isinstance(selectable, Recipe):
+                selectable = selectable.subquery()
+            elif isinstance(selectable, str):
+                if "." in selectable:
+                    schema, tablename = selectable.split(".")
+                else:
+                    schema, tablename = None, selectable
+
+                selectable = Table(
+                    tablename,
+                    metadata,
+                    schema=schema,
+                    extend_existing=True,
+                    autoload=True,
+                )
+
+            builder = SQLAlchemyBuilder.get_builder(
+                selectable=selectable,
+                cache=ingredient_cache,
+                extra_selectables=extra_selectables,
+                constants=constants,
+            )
 
         for k, v in validated_shelf.items():
-            if builder is None:
-                builder = SQLAlchemyBuilder.get_builder(
-                    selectable=selectable,
-                    cache=ingredient_cache,
-                    extra_selectables=extra_selectables,
-                    constants=constants,
-                )
             d[k] = ingredient_from_validated_dict(v, selectable, builder=builder)
 
             if isinstance(d[k], InvalidIngredient):
                 if not d[k].error.get("extra"):
                     d[k].error["extra"] = {}
                 d[k].error["extra"]["ingredient_name"] = k
-        shelf = cls(d, select_from=selectable)
+
+        engine = builder.selectable.bind
+
+        # TODO: Evaluate how and if we're using select_from
+        shelf = cls(d, select_from=builder.selectable, engine=engine)
         if builder and ingredient_cache is not None:
             builder.save_cache()
 
@@ -469,7 +478,7 @@ class Shelf(object):
         for key in order_by_keys:
             try:
                 ingr = self.find(key, (Dimension, Metric))
-                for c in ingr.order_by_columns:
+                for c in ingr.order_by_columns(engine=self.Meta.engine):
                     # Avoid duplicate order by columns
                     if str(c) not in [str(o) for o in order_bys]:
                         order_bys[c] = None
