@@ -75,6 +75,7 @@ class BuildGrammarTestCase(RecipeTestCase):
             ["num", "str", "str"],
             ["date", "datetime", "num", "str", "str"],
             ["num"],
+            ["str"],
         ]
 
         for selectable, expected_column_keys in zip(
@@ -89,6 +90,23 @@ class BuildGrammarTestCase(RecipeTestCase):
         with self.assertRaises(Exception):
             make_column_collection_for_selectable("foo")
 
+    def test_drivername(self):
+        expected_drivernames = [
+            "sqlite",
+            "sqlite",
+            "sqlite",
+            "sqlite",
+            "unknown",
+            "unknown",
+        ]
+
+        for selectable, expected_drivername in zip(
+            self.selectables, expected_drivernames
+        ):
+            b = SQLAlchemyBuilder(selectable)
+            print(b, b.drivername)
+            self.assertEqual(b.drivername, expected_drivername)
+
     def test_make_columns_grammar(self):
         expected_grammars = [
             """
@@ -891,6 +909,20 @@ class TestDataTypesTableDatesInBigquery(TestDataTypesTableDates):
         quarter([test_date]) > date("2020-12-30")        -> date_trunc(datatypes.test_date, quarter) > '2020-12-30'
         year([test_date]) > date("2020-12-30")           -> date_trunc(datatypes.test_date, year) > '2020-12-30'
         date([test_datetime])                            -> datetime(timestamp_trunc(datatypes.test_datetime, day))
+        # Datediff works on dates and defaults to day
+        datediff([test_date], [test_date])               -> date_diff(datatypes.test_date, datatypes.test_date, day)
+        datediff([test_date], [test_date], day)          -> date_diff(datatypes.test_date, datatypes.test_date, day)
+        datediff([test_date], [test_date], week)         -> date_diff(datatypes.test_date, datatypes.test_date, week)
+        datediff([test_date], [test_date], year)         -> date_diff(datatypes.test_date, datatypes.test_date, year)
+        datediff([test_date], [test_date], week(monday)) -> date_diff(datatypes.test_date, datatypes.test_date, week(monday))
+        # Extract works on both dates and datetimes
+        extract(day, [test_date])                        -> EXTRACT(day FROM datatypes.test_date)
+        extract(week(monday), [test_date])               -> EXTRACT(week(monday) FROM datatypes.test_date)
+        extract(day, [test_datetime])                    -> EXTRACT(day FROM datatypes.test_datetime)
+        extract(week(monday), [test_datetime])           -> EXTRACT(week(monday) FROM datatypes.test_datetime)
+        # Last day works on both dates and datetimes and defaults to month
+        lastday([test_datetime], week(monday))           -> last_day(datatypes.test_datetime, week(monday))
+        lastday([test_date])                             -> last_day(datatypes.test_date, month)
         """
 
         for field, expected_sql in self.examples(good_examples):
@@ -1179,16 +1211,21 @@ class TestIsValidColumn(GrammarTestCase):
             "this_that_and_other",
             "_other",
             "THIS_that_",
+            "that ",
+            "TH AT  ",
+            "x",
+            "_",
+            "5",
+            "_5",
         ]
         for v in good_values:
             self.assertTrue(is_valid_column(v))
 
         bad_values = [
-            " this",
-            "that ",
-            " THIS",
-            "TH AT  ",
             "for_slackbot}_organization_name",
+            " this",
+            " THIS",
+            "this_that-and-other",
         ]
         for v in bad_values:
             self.assertFalse(is_valid_column(v))
