@@ -12,6 +12,7 @@ from recipe.extensions import (
     CompareRecipe,
     Paginate,
     PaginateInline,
+    PaginateCountOver,
     RecipeExtension,
     SummarizeOver,
     handle_directives,
@@ -25,7 +26,7 @@ def convert_to_json_encoded(d: dict) -> dict:
     newd = {}
     for k, v in d.items():
         if "," in k and isinstance(v, list):
-            v = [dumps(itm) if not isinstance(itm, str) else itm for itm in v]
+            v = [itm if isinstance(itm, str) else dumps(itm) for itm in v]
         newd[k] = v
     return newd
 
@@ -218,6 +219,7 @@ class AutomaticFiltersTestCase(RecipeTestCase):
             {"exclude_automatic_filter_keys": ["potato"]},
             {"exclude_automatic_filter_keys": []},
             {"apply_automatic_filters": True},
+            {"strict_automatic_filters": True},
         ]
         for extra_config in valid_configs:
             config = copy(base_config)
@@ -423,6 +425,7 @@ class AutomaticFiltersTestCase(RecipeTestCase):
             {
                 "metrics": ["age"],
                 "dimensions": ["first"],
+                "strict_automatic_filters": True,
                 "automatic_filters": {
                     "potato,first": [["foo", "moo"], ["chicken", "cluck"]]
                 },
@@ -431,6 +434,49 @@ class AutomaticFiltersTestCase(RecipeTestCase):
             with self.assertRaises(BadRecipe):
                 recipe.to_sql()
 
+    def test_automatic_filters_with_unknown_dim_nostrict(self):
+        """Test filters built using an unknown dimension"""
+        for recipe in self.recipe_list(
+            {
+                "metrics": ["age"],
+                "dimensions": ["first"],
+                "strict_automatic_filters": False,
+                "automatic_filters": {"first": ["foo"], "potato": ["pancake"]},
+            },
+            {
+                "metrics": ["age"],
+                "dimensions": ["first"],
+                "strict_automatic_filters": False,
+                "automatic_filters": {"first": ["foo"], "potato__in": ["pancake"]},
+            },
+            {
+                "metrics": ["age"],
+                "dimensions": ["first"],
+                "strict_automatic_filters": False,
+                "automatic_filters": {"first": [None], "potato": "pancake"},
+            },
+            # Compound filters with unknown key
+            {
+                "metrics": ["age"],
+                "dimensions": ["first"],
+                "strict_automatic_filters": False,
+                "automatic_filters": {
+                    "first,potato": [["foo", "moo"], ["chicken", "cluck"]]
+                },
+            },
+            {
+                "metrics": ["age"],
+                "dimensions": ["first"],
+                "strict_automatic_filters": False,
+                "automatic_filters": {
+                    "potato,first": [["foo", "moo"], ["chicken", "cluck"]]
+                },
+            },
+        ):
+            # SQL gets generated filtering on foo.first, the potato ingredient is ignored
+            self.assertRecipeSQLContains(recipe, "WHERE foo.first")
+            self.assertRecipeSQLNotContains(recipe, "potato")
+
     def test_apply_automatic_filters(self):
         recipe = (
             self.recipe()
@@ -639,6 +685,54 @@ class AutomaticFiltersTestCase(RecipeTestCase):
                 recipe.all()
             self.assertEqual(str(cm.exception), error_msg)
 
+    def test_invalid_compound_filters_nostrict(self):
+        bad_compound_filters = [
+            # Values must be either lists or json encoded lists
+            (
+                {"first,last": ['"foo"']},
+                "Compound filter values must be json encoded lists",
+            ),
+            # Value must be valid json
+            ({"first,last": ['["foo"']}, "Compound filter values must be valid json"),
+            # Keys must be comma delimited valid dimensions
+            # ({"first,potato": ['["moo", "cow"]']}, "potato doesn't exist on the shelf")
+        ]
+
+        for bad_filter, error_msg in bad_compound_filters:
+            with self.assertRaises((ValueError, BadRecipe)) as cm:
+                recipe = self.recipe_from_config(
+                    {
+                        "metrics": ["age"],
+                        "dimensions": ["first"],
+                        "automatic_filters": bad_filter,
+                        "strict_automatic_filters": False,
+                        "exclude_automatic_filter_keys": ["foo"],
+                    }
+                )
+                recipe.all()
+            self.assertEqual(str(cm.exception), error_msg)
+
+        recipe = self.recipe_from_config(
+            {
+                "metrics": ["age"],
+                "dimensions": ["first"],
+                "automatic_filters": {"first,potato": ['["moo", "cow"]']},
+                "strict_automatic_filters": False,
+                "exclude_automatic_filter_keys": ["foo"],
+            }
+        )
+        # Same as {"first": ["moo"]}
+        self.assertRecipeSQL(
+            recipe,
+            """
+SELECT foo.first AS first,
+    sum(foo.age) AS age
+FROM foo
+WHERE foo.first = 'moo'
+GROUP BY first
+            """,
+        )
+
     def test_invalid_operators(self):
         """Invalid operators raise an exception"""
         # Testing operators
@@ -649,6 +743,7 @@ class AutomaticFiltersTestCase(RecipeTestCase):
                     "metrics": ["age"],
                     "dimensions": ["first"],
                     "automatic_filters": af,
+                    "strict_automatic_filters": True,
                     "exclude_automatic_filter_keys": ["foo"],
                 }
             ):
@@ -1213,6 +1308,79 @@ class PaginateInlineTestCase(PaginateTestCase):
         )
 
 
+class PaginateCountOverTestCase(PaginateTestCase):
+    """Run all the paginate tests with a different paginator
+
+    PaginateInline will add a "_total_count" column to each returned row.
+    Be sure to ignore this when evaluating results.
+    """
+
+    extension_classes = [PaginateCountOver]
+
+    def assertRecipeCSV(self, recipe: Recipe, csv_text: str):
+        super().assertRecipeCSV(recipe, csv_text, ignore_columns=["_total_count"])
+
+    def test_pagination_q_idvalue(self):
+        """Pagination queries use the value of an id value dimension"""
+        recipe = self.recipe_from_config(
+            {
+                "metrics": ["pop2000"],
+                "dimensions": ["idvalue_state"],
+                "pagination_page_size": 10,
+                "pagination_q": "State:T%",
+            }
+        )
+        self.assertRecipeCSV(
+            recipe,
+            """
+            idvalue_state_id,idvalue_state,pop2000
+            Tennessee,State:Tennessee,5685230
+            """,
+        )
+
+        self.assertRecipeCSV(
+            recipe,
+            """
+            idvalue_state_id,idvalue_state,pop2000
+            Tennessee,State:Tennessee,5685230
+            """,
+        )
+
+    def test_count_over_sql(self):
+        """Test all pagination options together"""
+        recipe = self.recipe_from_config(
+            {
+                "metrics": ["pop2000"],
+                "dimensions": ["state", "sex", "age"],
+                "pagination_page_size": 10,
+                "pagination_page": 5,
+                "pagination_q": "T%",
+                "pagination_search_keys": ["state", "sex"],
+            }
+        )
+        self.assertRecipeSQL(
+            recipe,
+            """
+            SELECT census.age AS age,
+                census.sex AS sex,
+                census.state AS state,
+                sum(census.pop2000) AS pop2000,
+                count(*) OVER () AS _total_count
+            FROM census
+            WHERE lower(census.state) LIKE lower('T%')
+            OR lower(census.sex) LIKE lower('T%')
+            GROUP BY age,
+                    sex,
+                    state
+            ORDER BY state,
+                    sex,
+                    age
+            LIMIT 10
+            OFFSET 40
+        """,
+        )
+
+
 class CompareRecipeTestCase(RecipeTestCase):
     extension_classes = [CompareRecipe]
 
