@@ -1053,9 +1053,7 @@ ORDER BY state_raw""",
 
 
 class TestMultipleSelectables(ConfigTestBase):
-    def test_multi_selectable(self):
-        """A shelf can reference multiple selectables"""
-        shelf_config = """
+    shelf_config = """
 username:
   kind: Dimension
   field: username
@@ -1085,12 +1083,17 @@ tagscoresscore:
   filter: tagscores.username = username
         """
 
-        shelf = self.shelf_from_yaml(
-            shelf_config,
+    def make_shelf(self):
+        return self.shelf_from_yaml(
+            self.shelf_config,
             self.scores_with_nulls_table,
             extra_selectables=[(self.tagscores_table, "tagscores")],
         )
 
+    def test_multi_selectable(self):
+        """Using a shelf can reference multiple selectables"""
+        shelf = self.make_shelf()
+
         recipe = self.recipe(shelf=shelf).metrics("score").dimensions("department")
         self.assertRecipeSQL(
             recipe,
@@ -1209,6 +1212,19 @@ sales,80.0,sales
         )
 
 
+class TestShelfFromBuilder(TestMultipleSelectables):
+    def make_shelf(self):
+        from recipe.schemas.builders import SQLAlchemyBuilder
+
+        builder = SQLAlchemyBuilder.get_builder(
+            self.scores_with_nulls_table,
+            extra_selectables=[(self.tagscores_table, "tagscores")],
+        )
+
+        # no selectable is passed, it's used in the builder
+        return self.shelf_from_yaml(self.shelf_config, None, builder=builder)
+
+
 class TestParsedSQLGeneration(ConfigTestBase):
     """More tests of SQL generation on complex parsed expressions"""
 
@@ -1306,9 +1322,36 @@ math:
 parentheses:
     kind: Metric
     field: "@count_star / (@count_star + (12.0 / 2.0))"
+maxdate:
+    kind: Metric
+    field: max(test_date)
+mindate:
+    kind: Metric
+    field: min(test_date)
+datediff:
+    kind: Metric
+    field: datediff(max(test_date), min(test_date))
 """,
             self.scores_with_nulls_table,
         )
+
+        # Test datediff
+        recipe = self.recipe(shelf=shelf).metrics("maxdate", "mindate", "datediff")
+        self.assertRecipeSQL(
+            recipe,
+            """SELECT CAST(julianday(max(scores_with_nulls.test_date)) AS INTEGER) - CAST(julianday(min(scores_with_nulls.test_date)) AS INTEGER) AS datediff,
+       max(scores_with_nulls.test_date) AS maxdate,
+       min(scores_with_nulls.test_date) AS mindate
+FROM scores_with_nulls""",
+        )
+        self.assertRecipeCSV(
+            recipe,
+            """
+            datediff,maxdate,mindate
+            31,2005-02-02,2005-01-02
+            """,
+        )
+
         recipe = self.recipe(shelf=shelf).metrics("count_star")
         self.assertRecipeSQL(
             recipe,
